@@ -6,6 +6,7 @@ use namespace::autoclean;
 use Moose::Role;
 
 use CatalystX::I18N::TypeConstraints;
+use MooseX::Types::DateTime;
 
 use Carp qw(carp);
 use DateTime;
@@ -16,7 +17,7 @@ use DateTime::Locale;
 
 has 'i18n_datetime_timezone' => (
     is      => 'rw', 
-    isa     => 'CatalystX::I18N::Type::DateTimeTimezone',
+    isa     => 'DateTime::TimeZone',
     lazy_build=> 1,
     builder => '_build_i18n_datetime_timezone',
     clearer => '_clear_i18n_datetime_timezone',
@@ -24,7 +25,7 @@ has 'i18n_datetime_timezone' => (
 
 has 'i18n_datetime_locale' => (
     is      => 'rw',
-    isa     => 'CatalystX::I18N::Type::DateTimeLocale',
+    isa     => 'DateTime::Locale',
     lazy_build=> 1,
     builder => '_build_i18n_datetime_locale',
     clearer => '_clear_i18n_datetime_locale',
@@ -163,7 +164,7 @@ CatalystX::I18N::Role::DateTime - Support for I18N datetime
 
 =head1 DESCRIPTION
 
-This role add support for localized datetime to your Catalyst application.
+This role add support for localised datetime to your Catalyst application.
 
 Most methods are lazy. This means that the values will be only calculated
 upon the first call of the method.
@@ -171,7 +172,7 @@ upon the first call of the method.
 Most settings will be taken from L<DateTime::Locale> but 
 can be overdriven in your Catalyst I18N configuration:
 
- # Add some I18N configuration
+ # Add I18N configuration
  __PACKAGE__->config( 
      name    => 'MyApp', 
      I18N    => {
@@ -220,7 +221,7 @@ Returns/sets the current datetime locale as a L<DateTime::Locale> object.
  my $date = $c->i18n_datetime_format_date->format_datetime($date);
 
 Returns a L<DateTime::Format::CLDR> object for parsing and printig 
-localized date data.
+localised date data.
 
 The format for each locale can either be set via the
 C<format_date> coniguration key, or will be taken from the 
@@ -231,7 +232,7 @@ C<date_format_medium> method in the current L<DateTime::Locale> object.
  my $datetime = $c->i18n_datetime_format_datetime->format_datetime($datetime);
 
 Returns a L<DateTime::Format::CLDR> object for parsing and printig 
-localized datetime data.
+localised datetime data.
 
 The format for each locale can either be set via the
 C<format_datetime> coniguration key, or will be taken from the 
