@@ -4,13 +4,13 @@ use strict;
 use warnings;
 
 use parent 'Catalyst::View';
-use JSON::Any;
+use JSON;
 
 sub process {
     my ( $self, $c, $response) = @_;
 
     $c->response->content_type('application/json; charset=utf-8');
-    $c->response->body(JSON::Any->objToJson($response || $c->stash));
+    $c->response->body(encode_json($response || $c->stash));
     
     return;
 }
